import http.client
import hashlib
import urllib
import random
import json
import time
from fairies import file_utils

def zh_to_en(word_lists):

    """
        只会返回前200的单词翻译
        使用百度api
    """

    appid = '20201107000610595'  # 填写你的appid
    secretKey = 'EylFfm6wOcWQRNaI3LZ9'  # 填写你的密钥

    httpClient = None
    myurl = '/api/trans/vip/translate'

    final_res = []
    count = 0
    for i in word_lists[:200]:
        count += 1

        if count % 50 == 0:
            time.sleep(30)        
        else:    
            time.sleep(1)
        try:

            fromLang = 'zh'   #原文语种
            toLang = 'en'   #译文语种
            salt = random.randint(32768, 65536)
            q = i
            sign = appid + q + str(salt) + secretKey
            sign = hashlib.md5(sign.encode()).hexdigest()
            myurl = myurl + '?appid=' + appid + '&q=' + urllib.parse.quote(q) + '&from=' + fromLang + '&to=' + toLang + '&salt=' + str(
            salt) + '&sign=' + sign

            httpClient = http.client.HTTPConnection('api.fanyi.baidu.com')
            httpClient.request('GET', myurl)

            # response是HTTPResponse对象
            response = httpClient.getresponse()
            result_all = response.read().decode("utf-8")
            result = json.loads(result_all)

            print('正在请求...')
            print(result)
            re = result['trans_result'][0]['dst']
            final_res.append(re)

        except Exception as e:
            print (e)
        finally:
            if httpClient:
                httpClient.close()
    
    return final_res

def en_to_zh(word_lists):

    """
        只会返回前200的单词翻译
        使用百度api
    """

    appid = '20201107000610595'  # 填写你的appid
    secretKey = 'EylFfm6wOcWQRNaI3LZ9'  # 填写你的密钥

    httpClient = None
    myurl = '/api/trans/vip/translate'


    final_res = []
    count = 0
    for i in word_lists[:200]:
        count += 1

        if count % 50 == 0:
            time.sleep(30)        
        else:    
            time.sleep(1)
        try:

            fromLang = 'en'   #原文语种
            toLang = 'zh'   #译文语种
            salt = random.randint(32768, 65536)
            q = i
            sign = appid + q + str(salt) + secretKey
            sign = hashlib.md5(sign.encode()).hexdigest()
            myurl = myurl + '?appid=' + appid + '&q=' + urllib.parse.quote(q) + '&from=' + fromLang + '&to=' + toLang + '&salt=' + str(
            salt) + '&sign=' + sign

            httpClient = http.client.HTTPConnection('api.fanyi.baidu.com')
            httpClient.request('GET', myurl)

            # response是HTTPResponse对象
            response = httpClient.getresponse()
            result_all = response.read().decode("utf-8")
            result = json.loads(result_all)

            print('正在请求...')
            print(result)
            re = result['trans_result'][0]['dst']
            final_res.append(re)

        except Exception as e:
            print (e)
        finally:
            if httpClient:
                httpClient.close()
    
    return final_res

def translate(from_type,to_type,word_lists):

    """
        支持任何语言种类间的转换

        # 自动检测 auto
        # 中文 zh
        # 英语 en
        # 粤语 yue
        # 文言文 wyw
        # 日语 jp
        # 韩语 kor
        # 法语 fra
        # 西班牙语 spa
        # 泰语 th
        # 阿拉伯语 ara
        # 俄语 ru
        # 葡萄牙语 pt
        # 德语 de
        # 意大利语 it
        # 希腊语 el
        # 荷兰语 nl
        # 波兰语 pl
        # 保加利亚语 bul
        # 爱沙尼亚语 est
        # 丹麦语 dan
        # 芬兰语 fin
        # 捷克语 cs
        # 罗马尼亚语 rom
        # 斯洛文尼亚语 slo
        # 瑞典语 swe
        # 匈牙利语 hu
        # 繁体中文 cht
        # 越南语 vie
        
    """

    appid = '20201107000610595'  # 填写你的appid
    secretKey = 'EylFfm6wOcWQRNaI3LZ9'  # 填写你的密钥

    httpClient = None
    myurl = '/api/trans/vip/translate'

    final_res = []
    count = 0
    for i in word_lists[:200]:
        count += 1

        if count % 50 == 0:
            time.sleep(30)        
        else:    
            time.sleep(1)
        try:

            fromLang = from_type   #原文语种
            toLang = to_type   #译文语种
            salt = random.randint(32768, 65536)
            q = i
            sign = appid + q + str(salt) + secretKey
            sign = hashlib.md5(sign.encode()).hexdigest()
            myurl = myurl + '?appid=' + appid + '&q=' + urllib.parse.quote(q) + '&from=' + fromLang + '&to=' + toLang + '&salt=' + str(
            salt) + '&sign=' + sign

            httpClient = http.client.HTTPConnection('api.fanyi.baidu.com')
            httpClient.request('GET', myurl)

            # response是HTTPResponse对象
            response = httpClient.getresponse()
            result_all = response.read().decode("utf-8")
            result = json.loads(result_all)

            print('正在请求...')
            print(result)
            re = result['trans_result'][0]['dst']
            final_res.append(re)

        except Exception as e:
            print (e)
        finally:
            if httpClient:
                httpClient.close()
    
    return final_res        


import re
import matplotlib.mlab as mlab  
import matplotlib.pyplot as plt  

def text_len_analysis(texts):
    
    """
    可视化文本长度
    param texts 需要分析的文本数组
    
    """

    length = []

    for i in texts:
        length.append(len(i))
    
    fig = plt.figure()
    ax = fig.add_subplot()
    ax.hist(length, bins=10, color='blue', alpha=0.7)
    plt.show()

def dict_bar(dicts):

    # TODO 元素太多标签看不清

    # 这两行代码解决 plt 中文显示的问题
    plt.rcParams['font.sans-serif'] = ['SimHei']
    plt.rcParams['axes.unicode_minus'] = False

    # 字典转元组
    x = tuple(dicts)
    y = tuple(dicts.values())

    plt.bar(x, y, width= 1)
    plt.show()


def split_to_paragraph(content, filter_length=(2, 1000)):

    """
        拆分成段落
    """
    
    content = re.sub(r"\s*", "", content)
    content = re.sub("([。！…？?!；;])", "\\1\1", content)
    sents = content.split("\1")
    sents = [_[: filter_length[1]] for _ in sents]

    res = []
    temp = ''
    for _ in sents:
        if len(temp + _ ) > filter_length[1]:
            res.append(temp)
            temp = _
        else:
            temp = temp + _
    if len(temp) > 0:
        res.append(temp)

    return res

def split_to_sents(content, filter_length=(2, 1000)):

    """
        拆分成句子
    """
    content = re.sub(r"\s*", "", content)
    content = re.sub("([。])", "\\1\1", content)
    sents = content.split("\1")
    sents = [_[: filter_length[1]] for _ in sents]
    return [_ for _ in sents
            if filter_length[0] <= len(_) <= filter_length[1]]

def split_to_subsents(content, filter_length=(2, 1000)):

    """
        拆分成子句
    """

    content = re.sub(r"\s*", "", content)
    content = re.sub("([。！…？?!；;,，])", "\\1\1", content)
    sents = content.split("\1")
    sents = [_[: filter_length[1]] for _ in sents]
    return [_ for _ in sents
            if filter_length[0] <= len(_) <= filter_length[1]]


def get_slide_window_text(text,maxlen,window):

    """
    使用移动窗口的方式分割text
    基于','分割文本,尽可能保留更多完整的信息,而不是根据字数强行分割
    
    param text 需要处理的文本
          maxlen 分割成文本的最大长度 需要小于1000
          window 滑动窗口长度
    """

    lists = split_to_subsents(text)
    lists_len = [len(i) for i in lists]

    # 在滑动的时候尽量保存完整的信息
    # 找到开始的位置

    start = 0
    sumTemp = 0

    cut_list = []

    for i in range(len(lists_len)):
        if sumTemp + lists_len[i]< maxlen:
            sumTemp += lists_len[i]
        else:
            if len(lists_len) > 1:
                cut_list.append([start,max(i-1,start)])
                sumTemp = sumTemp - lists_len[start]
                start += 1
                while sumTemp > maxlen - window :
                    if start + 1 < i - 1:
                        start += 1
                        sumTemp = sumTemp - lists_len[start]
                    else:
                        start = max(i-1,start)
                        sumTemp = lists_len[start]
                        break
                sumTemp += lists_len[i]

        if i == len(lists_len) -1 :
            cut_list.append([start,i])

    res = [] 

    for i in cut_list:
        new = ''
        for k in range(i[0],i[1]+1):
            new += lists[k]
        res.append(new)    

    return res


def get_cut_window_text(text,maxlen,window):
    
    """
    使用截断的方式分割text
    基于','分割文本,尽可能保留更多完整的信息,而不是根据字数强行分割
    
    param text 需要处理的文本
          maxlen 分割成文本的最大长度 需要小于1000
          window 滑动窗口长度
    """
    textlen = len(text)

    start = 0
    end = maxlen
    lists = []

    while end < textlen:
        lists.append([start,end+1])
        start += window
        end += window

    if start < textlen:
        lists.append([start,textlen])

    res = []

    for i in lists:
        res.append(text[i[0]:i[1]])

    return res


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from copy import deepcopy

import re

try:
    import psyco

    psyco.full()
except:
    pass

try:
    from zh_wiki import zh2Hant, zh2Hans
except ImportError:
    from fairies.zh_wiki import zh2Hant, zh2Hans

import sys

py3k = sys.version_info >= (3, 0, 0)

if py3k:
    UEMPTY = ''
else:
    _zh2Hant, _zh2Hans = {}, {}
    for old, new in ((zh2Hant, _zh2Hant), (zh2Hans, _zh2Hans)):
        for k, v in old.items():
            new[k.decode('utf8')] = v.decode('utf8')
    zh2Hant = _zh2Hant
    zh2Hans = _zh2Hans
    UEMPTY = ''.decode('utf8')

# states
(START, END, FAIL, WAIT_TAIL) = list(range(4))
# conditions
(TAIL, ERROR, MATCHED_SWITCH, UNMATCHED_SWITCH, CONNECTOR) = list(range(5))

MAPS = {}


class Node(object):
    def __init__(self, from_word, to_word=None, is_tail=True,
                 have_child=False):
        self.from_word = from_word
        if to_word is None:
            self.to_word = from_word
            self.data = (is_tail, have_child, from_word)
            self.is_original = True
        else:
            self.to_word = to_word or from_word
            self.data = (is_tail, have_child, to_word)
            self.is_original = False
        self.is_tail = is_tail
        self.have_child = have_child

    def is_original_long_word(self):
        return self.is_original and len(self.from_word) > 1

    def is_follow(self, chars):
        return chars != self.from_word[:-1]

    def __str__(self):
        return '<Node, %s, %s, %s, %s>' % (repr(self.from_word),
                                           repr(self.to_word), self.is_tail, self.have_child)

    __repr__ = __str__

class ConvertMap(object):
    def __init__(self, name, mapping=None):
        self.name = name
        self._map = {}
        if mapping:
            self.set_convert_map(mapping)

    def set_convert_map(self, mapping):
        convert_map = {}
        have_child = {}
        max_key_length = 0
        for key in sorted(mapping.keys()):
            if len(key) > 1:
                for i in range(1, len(key)):
                    parent_key = key[:i]
                    have_child[parent_key] = True
            have_child[key] = False
            max_key_length = max(max_key_length, len(key))
        for key in sorted(have_child.keys()):
            convert_map[key] = (key in mapping, have_child[key],
                                mapping.get(key, UEMPTY))
        self._map = convert_map
        self.max_key_length = max_key_length

    def __getitem__(self, k):
        try:
            is_tail, have_child, to_word = self._map[k]
            return Node(k, to_word, is_tail, have_child)
        except:
            return Node(k)

    def __contains__(self, k):
        return k in self._map

    def __len__(self):
        return len(self._map)


class StatesMachineException(Exception): pass


class StatesMachine(object):
    def __init__(self):
        self.state = START
        self.final = UEMPTY
        self.len = 0
        self.pool = UEMPTY

    def clone(self, pool):
        new = deepcopy(self)
        new.state = WAIT_TAIL
        new.pool = pool
        return new

    def feed(self, char, map):
        node = map[self.pool + char]

        if node.have_child:
            if node.is_tail:
                if node.is_original:
                    cond = UNMATCHED_SWITCH
                else:
                    cond = MATCHED_SWITCH
            else:
                cond = CONNECTOR
        else:
            if node.is_tail:
                cond = TAIL
            else:
                cond = ERROR

        new = None
        if cond == ERROR:
            self.state = FAIL
        elif cond == TAIL:
            if self.state == WAIT_TAIL and node.is_original_long_word():
                self.state = FAIL
            else:
                self.final += node.to_word
                self.len += 1
                self.pool = UEMPTY
                self.state = END
        elif self.state == START or self.state == WAIT_TAIL:
            if cond == MATCHED_SWITCH:
                new = self.clone(node.from_word)
                self.final += node.to_word
                self.len += 1
                self.state = END
                self.pool = UEMPTY
            elif cond == UNMATCHED_SWITCH or cond == CONNECTOR:
                if self.state == START:
                    new = self.clone(node.from_word)
                    self.final += node.to_word
                    self.len += 1
                    self.state = END
                else:
                    if node.is_follow(self.pool):
                        self.state = FAIL
                    else:
                        self.pool = node.from_word
        elif self.state == END:
            # END is a new START
            self.state = START
            new = self.feed(char, map)
        elif self.state == FAIL:
            raise StatesMachineException('Translate States Machine '
                                         'have error with input data %s' % node)
        return new

    def __len__(self):
        return self.len + 1

    def __str__(self):
        return '<StatesMachine %s, pool: "%s", state: %s, final: %s>' % (
            id(self), self.pool, self.state, self.final)

    __repr__ = __str__


class Converter(object):
    def __init__(self, to_encoding):
        self.to_encoding = to_encoding
        self.map = MAPS[to_encoding]
        self.start()

    def feed(self, char):
        branches = []
        for fsm in self.machines:
            new = fsm.feed(char, self.map)
            if new:
                branches.append(new)
        if branches:
            self.machines.extend(branches)
        self.machines = [fsm for fsm in self.machines if fsm.state != FAIL]
        all_ok = True
        for fsm in self.machines:
            if fsm.state != END:
                all_ok = False
        if all_ok:
            self._clean()
        return self.get_result()

    def _clean(self):
        if len(self.machines):
            self.machines.sort(key=lambda x: len(x))
            # self.machines.sort(cmp=lambda x,y: cmp(len(x), len(y)))
            self.final += self.machines[0].final
        self.machines = [StatesMachine()]

    def start(self):
        self.machines = [StatesMachine()]
        self.final = UEMPTY

    def end(self):
        self.machines = [fsm for fsm in self.machines
                         if fsm.state == FAIL or fsm.state == END]
        self._clean()

    def convert(self, string):
        self.start()
        for char in string:
            self.feed(char)
        self.end()
        return self.get_result()

    def get_result(self):
        return self.final


def registery(name, mapping):
    global MAPS
    MAPS[name] = ConvertMap(name, mapping)


registery('zh-hant', zh2Hant)
registery('zh-hans', zh2Hans)
del zh2Hant, zh2Hans


def run():
    import sys
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option('-e', type='string', dest='encoding',
                      help='encoding')
    parser.add_option('-f', type='string', dest='file_in',
                      help='input file (- for stdin)')
    parser.add_option('-t', type='string', dest='file_out',
                      help='output file')
    (options, args) = parser.parse_args()
    if not options.encoding:
        parser.error('encoding must be set')
    if options.file_in:
        if options.file_in == '-':
            file_in = sys.stdin
        else:
            file_in = open(options.file_in)
    else:
        file_in = sys.stdin
    if options.file_out:
        if options.file_out == '-':
            file_out = sys.stdout
        else:
            file_out = open(options.file_out, 'wb')
    else:
        file_out = sys.stdout

    c = Converter(options.encoding)
    for line in file_in:
        # print >> file_out, c.convert(line.rstrip('\n').decode(
        file_out.write(c.convert(line.rstrip('\n').decode('utf8')).encode('utf8'))


if __name__ == '__main__':
    run()



tongxing =[
    "宗棕综踪淙崇",
    "帛绵棉锦",
    "夫扶肤",
    "粮酿浪良",
    "通桶痛",
    "慢漫幔馒",
    "拌绊伴胖",
    "赧赦",
    "主注往柱驻住",
    "兵滨缤摈傧宾",
    "圩盱纡吁",
    "腊蜡",
    "促捉",
    "秀锈绣诱透",
    "帅师",
    "漠晒躁芒练诗挂",
    "末未味抹",
    "耐惴阅悦",
    "品晶",
    "直植值殖置",
    "登凳橙噔蹬瞪",
    "加驾架",
    "换焕唤央",
    "用拥佣",
    "更硬便梗更",
    "攀拳掌撑",
    "喜熹嬉嘻",
    "陶掏淘啕",
    "铭名茗酩",
    "阑澜斓",
    "贲喷愤",
    "摭遮",
    "非菲霏排悲匪辈徘徊",
    "暮蓦墓幕慕摹",
    "邦帮绑",
    "旦胆但担坦",
    "内柄纳呐",
    "京凉谅晾景惊掠",
    "我峨娥鹅",
    "拾给",
    "桥娇骄矫轿",
    "居剧据倨锯踞",
    "揪鳅",
    "半伴拌",
    "良娘狼酿",
    "编恨晴祥矫幅瑚",
    "模漠摸",
    "逢缝蓬篷峰锋逢蜂",
    "疆僵",
    "艰银很恨狠跟",
    "防访纺仿妨",
    "馈溃匮聩篑愦愦",
    "齐挤剂",
    "榆愉喻",
    "俊骏竣峻",
    "仓沧白伧枪抢",
    "慌眨末份侮凉旦",
    "熬傲遨鏖",
    "之乏芝泛",
    "蠕嚅濡孺懦",
    "盒盘盆",
    "历厉历励沥",
    "弈奕",
    "喋牒谍碟堞",
    "曼慢漫蔓馒幔",
    "寸村对才材财",
    "奖桨浆酱",
    "虐虑虚虔",
    "哭骂咒器嚣",
    "麻床",
    "瓜孤狐抓",
    "垂陲睡锤棰捶",
    "詹檐瞻",
    "亘恒宣喧楦渲桓垣晅萱暄喧瑄烜楦",
    "堂瞠膛",
    "叔淑椒督",
    "啜掇缀",
    "掏轮冷浪杨刚义",
    "甸句",
    "扁匾偏翩篇遍骗编蝙",
    "谡稷",
    "西洒晒酒",
    "涛铸",
    "郎朗",
    "彩采踩睬",
    "雀省",
    "里童埋理狸暑着",
    "尚淌倘躺趟",
    "巨拒炬距矩柜",
    "戢缉楫辑",
    "作昨",
    "扬杨汤场肠",
    "出屈拙倔掘咄",
    "票漂缥飘剽瓢膘",
    "泛眨乏贬",
    "衅畔叛判",
    "爪瓜爬抓",
    "碟蝶捧棒",
    "约药",
    "澈撤辙",
    "蓝篮",
    "妲怛袒",
    "辰唇晨震振辱",
    "庭挺艇蜓",
    "堂棠裳赏",
    "稿篙嵩蒿",
    "珍诊",
    "慢漫",
    "拣练炼",
    "调凋",
    "千纤迁",
    "尝偿赏裳",
    "杨惕赐踢",
    "勿忽匆葱",
    "成城诚盛",
    "板饭返扳贩",
    "蓦募宾滨",
    "包跑炮泡抱袍饱苞刨咆",
    "敝弊蔽",
    "饭租访饱披注逢",
    "雅稚",
    "纂篡",
    "兆挑桃窕逃",
    "穴窘穷空窈窕",
    "止址趾耻",
    "肖消悄稍捎霄哨",
    "类及考超尤导暑",
    "忖村讨对",
    "崔摧催",
    "章障彰獐",
    "区沤躯驱岖欧殴讴呕怄抠枢伛妪鸥",
    "灰恢诙炭",
    "则测侧铡",
    "长涨胀张",
    "平评苹萍",
    "果棵颗课稞",
    "富副幅逼福",
    "航杭抗炕",
    "真镇",
    "峻俊骏竣",
    "著着者",
    "薄搏博膊傅缚簿",
    "八扒趴穴",
    "旺汪茁拙",
    "挣净睁",
    "佰宿缩",
    "段断",
    "摘滴",
    "式试拭轼",
    "詹檐瞻赡谵",
    "油宙笛邮",
    "婉晚豌惋",
    "卓桌绰悼掉婥棹淖倬焯",
    "醇淳谆敦",
    "鬼瑰愧槐魏魄魂魁",
    "漆膝",
    "宥囿侑",
    "挪娜那哪",
    "昆混棍",
    "倦蜷眷卷券誉誊",
    "甘钳甜柑",
    "监滥槛",
    "麋鹿麇麂",
    "坚固厌雀拾左熟",
    "内缺找烟埋引绳",
    "魂魄魅魁",
    "是提题堤",
    "央奂涣唤换焕映英",
    "姆母拇",
    "偶遇寓藕隅",
    "劲径茎经颈",
    "婺骛鹜",
    "忻沂坎斫昕",
    "粟栗",
    "取职",
    "猬匹陈代比毫要",
    "坐块桶受挥源侧",
    "尧饶绕浇挠烧",
    "则测侧",
    "疆僵蜷倦",
    "脊瘠",
    "卒碎醉萃瘁粹翠悴",
    "尔你弥猕",
    "轮论伦沦",
    "荒谎慌",
    "斩渐崭暂",
    "硕项衰衷",
    "活还萍选蓓睬",
    "凉晾谅京",
    "十什计针叶汁",
    "找戏",
    "己记纪妃",
    "登凳橙蹬澄",
    "秕妣庇毖纰砒毗枇蚍",
    "冈刚钢岗纲",
    "建健键",
    "满瞒蹒",
    "斥诉拆",
    "率摔蟀",
    "具俱惧飓",
    "狐孤抓",
    "戍戎戊戌",
    "盎蛊盂盅",
    "幻幼",
    "票栗",
    "劝动功",
    "欣颀掀折",
    "面腼缅湎",
    "龚龛詟垄陇",
    "因咽胭烟",
    "扑朴补",
    "右石",
    "罗萝箩",
    "本笨体",
    "慕幕墓暮",
    "及乃",
    "干杆竿汗",
    "取创约委怕品摘",
    "具真其",
    "殳股役投没般设",
    "踝稞窠裸",
    "称你",
    "析浙拆折",
    "暴爆瀑曝",
    "摸酒澡茫炼特桂",
    "世屉泄蝶碟",
    "必密蜜秘",
    "怕帕",
    "贯惯贯掼",
    "官馆管棺",
    "秀绣锈透",
    "兽曾",
    "多侈移够哆",
    "亭停婷",
    "合哈拾答给塔搭恰",
    "究穷突",
    "者都煮暑署躇诸绪赌睹堵",
    "洒晒酒",
    "走趣趋越起趟超陡徒",
    "调雕凋碉",
    "支枝技歧鼓肢岐",
    "铺捕哺埔甫辅圃匍蒲",
    "跨垮挎胯",
    "谬缪缪戮戳",
    "亢坑炕抗吭",
    "唐糖塘搪",
    "连链莲",
    "翩跟睛",
    "卒率翠碎",
    "瞅啾揪锹楸湫",
    "皆谐楷",
    "火灭灾伙炎淡谈",
    "傲熬赘",
    "覆履屐复",
    "查渣碴",
    "胳骼恪络烙咯落格",
    "古枯估故做",
    "竟境镜竞",
    "状壮",
    "洁结桔",
    "乐砾烁",
    "爬抓",
    "麻磨蘑摩靡魔麾",
    "不丕歪否坏怀环环",
    "昔猎借错蜡惜腊鹊措",
    "货贷",
    "僖熹",
    "君群裙",
    "韦违韬苇讳伟",
    "吾语悟捂梧",
    "壁璧辟僻",
    "呙娲祸剐锅涡",
    "廷挺庭霆艇蜓",
    "峻俊骏竣浚悛逡唆梭焌",
    "维唯惟难",
    "吉结洁桔吉",
    "里童埋理狸暑著",
    "班斑",
    "虎虚",
    "谣摇遥",
    "力边动劫励历",
    "掏淘陶萄",
    "辛瓣辩辫辨 辞辟避宰辣",
    "瞭缭嘹镣",
    "丁订钉叮盯打",
    "奏凑挨",
    "诞蜒碗婉",
    "辨辫辩瓣",
    "嬴蠃羸赢",
    "崖涯",
    "申神伸坤绅",
    "琴瑟",
    "大犬夫天",
    "努怒弩奴",
    "夸挎垮胯跨",
    "渑绳蝇龟",
    "淘论领狼汤钢议",
    "惩征",
    "哥歌",
    "肚吐杜",
    "挟狭持待侍诗",
    "放旅旋族",
    "曾赠憎僧蹭嶒",
    "估轱沽牯钴诂怙祜佑",
    "状壮妆",
    "用拥佣甩",
    "鞠掬菊",
    "坏怀环还",
    "反版板饭返",
    "富福幅辐蝠副",
    "凑揍",
    "区欧沤躯驱岖",
    "诊珍趁",
    "殊铢",
    "金链键钱铜针",
    "度席",
    "掉卓桌",
    "牙呀芽雅讶",
    "般没投役",
    "资姿咨羡",
    "考老",
    "掩淹",
    "份粉纷分",
    "奇寄",
    "准站铺叮炕邮当",
    "采彩睬踩",
    "旁榜膀傍磅",
    "尚躺淌趟",
    "室宝",
    "荒乏味纷悔晾担",
    "免挽勉冕晚娩搀馋逸",
    "挤齐济",
    "卜补扑朴仆",
    "比此些",
    "顽烦顿",
    "粗租祖组阻",
    "也弛驰施",
    "采彩睬踩菜",
    "捷睫试拭",
    "格恪",
    "黑墨默黩黯黔",
    "眨泛乏之",
    "谎泛未粉海谅但",
    "告浩皓靠诰梏鹄",
    "概慨溉既",
    "买卖读渎椟黩犊续",
    "章彰樟璋蟑",
    "兑悦说脱",
    "尊奠",
    "毛毡毯毫",
    "敝弊蔽撇蹩瞥",
    "萄沦怜酿扬纲蚁",
    "显星湿",
    "占沾粘站战黏帖贴玷",
    "仓苍沧抢枪疮呛炝",
    "将奖浆蒋",
    "卓桌绰悼掉",
    "考烤拷铐",
    "风讽枫飘飚飒疯",
    "楼搂缕",
    "公讼松",
    "杜补剩其瞟直职",
    "睢雎哺捕脯铺匍匐圃",
    "挠绕饶烧",
    "亘恒宣喧楦渲",
    "合哈拾答给 塔搭恰",
    "崩蹦绷鹏",
    "警擎",
    "做坐座",
    "撕嘶期其",
    "于宇吁迂",
    "祛怯",
    "兹慈滋磁",
    "谓区阵伐此豪耍",
    "涡蜗",
    "萄淘陶掏",
    "玄弦舷眩",
    "娄屡缕偻搂数喽",
    "那哪挪娜",
    "交狡校郊胶效 跤饺绞咬",
    "甚堪斟勘湛",
    "嬉禧",
    "梧悟晤语",
    "貌藐",
    "每海梅悔诲霉",
    "堵赌睹著",
    "至到倒侄致",
    "复履复",
    "奂焕涣换",
    "荒慌谎",
    "斤近折听斩崭断",
    "古枯苦姑沽",
    "超起",
    "喂偎",
    "货度否历土用于",
    "侮海悔梅",
    "篇骗偏编遍翩",
    "闻问闷",
    "裕欲浴俗",
    "橙澄凳登",
    "妨彷",
    "提题堤",
    "烟咽",
    "羽翔翩翘翻翅翱翠",
    "曷渴喝竭褐揭碣遏偈",
    "谁唯维推雕难雅崔摧催璀稚雏",
    "台抬胎苔怡治冶始",
    "姑提愉辽烦级骆",
    "奄掩淹俺",
    "鹅饿娥峨",
    "向响晌",
    "堂党赏",
    "原愿源",
    "蛰蜇",
    "史驶使",
    "鸟馆昌菌昨恩铸",
    "摊贴浦订坑油铛",
    "诟逅",
    "返祖纺抱破往峰",
    "票刮塔室帅兽尊",
    "白怕帕伯拍泊柏陌珀",
    "浼娩冕晚挽",
    "当挡档",
    "辩趴偎穷转栏迅",
    "虫独浊蛋蚕",
    "冠寇",
    "童撞幢",
    "者诸猪储赌睹堵都煮",
    "月朋膊脯育肓脊背",
    "箫萧",
    "难粘哺钉抗笛挡",
    "豕逐琢啄",
    "囊壤攘镶嚷瓤",
    "赞攒",
    "崇祟综踪",
    "卖续读",
    "哲暂",
    "冈刚钢纲岗",
    "思恩",
    "门闲闷闭闯阔闪",
    "旁滂螃榜膀傍谤磅镑",
    "甩用",
    "少妙纱抄沙",
    "皆楷谐",
    "躁臊澡操噪燥藻",
    "灾灭",
    "贷席杏厉士甩干",
    "复腹覆馥蝮履",
    "极级吸",
    "奴努怒恕",
    "因困",
    "面腼缅",
    "乔骄桥轿娇侨 矫",
    "瓣叭畏突砖拦汛",
    "脏桩",
    "式拭试",
    "吾语捂悟梧",
    "奋愤锁销",
    "秋愁揪鳅",
    "管馆",
    "徘排",
    "此比",
    "骨滑猾",
    "员陨损",
    "兰拦栏烂",
    "檫擦",
    "贝责负贫贪财账赊贺货",
    "估堤喻疗顿吸络",
    "你壮塘妖淹杖困",
    "喂偎畏",
    "翎翔翘翩",
    "亦迹峦恋变弈奕蛮",
    "买买卖",
    "周凋调调绸雕稠",
    "甬通痛桶诵捅俑涌用拥佣",
    "暴爆曝瀑",
    "博搏",
    "买卖续读",
    "聿律津",
    "拦栏烂",
    "杨汤场扬",
    "人入",
    "国固",
    "贴帖粘站",
    "值植直",
    "沟钩钓钧",
    "炼练冻拣",
    "掐陷馅",
    "梨犁盆岔",
    "纤迁",
    "经茎泾径劲胫",
    "样祥详",
    "彻砌沏切",
    "宛碗婉腕蜿",
    "柜拒炬矩",
    "废怒捉凋灭备开",
    "遥庐瓜睁弧桔对",
    "赞替潜",
    "兹慈磁滋",
    "括坏平洗培彩显",
    "氏纸氐抵邸低底",
    "谋媒煤某",
    "桌济盆字赏纬渗",
    "弓引弯湾",
    "坐座挫",
    "王斑班狂枉琴瑟",
    "讨付对",
    "央秧映殃",
    "旦但担胆",
    "白怕拍伯泊柏",
    "床桩漫苞虚汁耸",
    "括适话活",
    "交狡校郊胶效跤饺绞咬",
    "欠次软低吹砍欣欢",
    "若苦狠狼",
    "缺缸",
    "曷渴喝竭褐揭",
    "冒昌",
    "靥魇",
    "彩踩菜睬",
    "幼窈坳拗",
    "经茎泾径劲",
    "成城诚",
    "岫柚轴舳",
    "士土",
    "汤烫",
    "乙乞艺忆迄屹亿",
    "敖熬傲遨赘",
    "家稼嫁",
    "委委萎魏",
    "喘揣端湍瑞惴",
    "车军浑挥晖辉",
    "舌活话括乱刮",
    "苘茼",
    "阵陈",
    "瑞端揣喘",
    "并拼饼迸",
    "悼掉",
    "煎剪",
    "蛮峦恋奕",
    "掣擎",
    "培赔陪倍",
    "昔惜措错腊蜡",
    "糖塘",
    "殄畛",
    "爱受援",
    "厉励沥历",
    "刍皱煞邹",
    "货袋贷代",
    "又权杈",
    "票飘漂膘",
    "临监鉴篮蓝",
    "坑吭抗炕",
    "职枪钓萎帕晶滴",
    "熟热",
    "骗银清洋娇富糊",
    "主住往注柱驻",
    "掉挤盒守堂伟参",
    "距巨拒炬",
    "锋蜂峰缝",
    "甬通痛桶诵捅俑涌",
    "传转砖",
    "舟航舰",
    "杳沓",
    "交郊皎咬胶姣佼绞狡",
    "唐塘搪糖",
    "怠殆骀饴怡贻贻",
    "堇谨勤",
    "谷俗裕豁浴",
    "帮邦绑梆",
    "饥肌机讥",
    "义议仪蚁",
    "侵寝监槛",
    "艮狠恨狼娘恳垦",
    "揭竭",
    "付付附腐符俯",
    "佥险检验脸签捡俭",
    "火灾烧煤烤炎焚",
    "见观现砚觉视",
    "莫墓暮幕慕模摸摹漠",
    "女妥要耍",
    "陶伦铃娘场岗仪",
    "勺匀勾钓均钩沟",
    "府付附附",
    "悲辈菲翡",
    "宁狞拧",
    "验检捡俭",
    "编遍扁蝙",
    "票飘漂瞟",
    "偏很情鲜骄副蝴",
    "勾构钩沟",
    "区匹",
    "犄犄掎犄畸崎绮漪旖倚",
    "粘沾",
    "相箱霜湘",
    "亢坑炕抗",
    "既溉慨概",
    "屋层",
    "牺栖洒晒哂",
    "缝逢峰烽蜂",
    "熟塾",
    "脉泳咏永",
    "市闹柿",
    "皮披波菠坡彼",
    "待诗特",
    "生性姓星",
    "马驼驮驱驰妈吗骂",
    "永咏泳脉",
    "莫漠寞摸模膜",
    "派旅",
    "焦蕉礁瞧憔樵",
    "替潜",
    "直值植殖",
    "洗宪冼选",
    "农浓农",
    "浅线钱贱践溅栈饯",
    "匀均钧",
    "咸减喊感",
    "刚钢岗纲",
    "副福富辐",
    "境镜竞竟",
    "夸垮跨挎胯污",
    "曼漫慢蔓谩幔馒",
    "竖国庆省给在热",
    "累螺",
    "舌刮乱恬括",
    "籍藉误娱",
    "遭糟踏蹋",
    "州洲渊",
    "斯撕嘶厮",
    "凉谅晾惊",
    "浪狼娘酿",
    "往住注驻",
    "周凋调绸稠惆碉雕",
    "劼桔桔诘拮枯",
    "耍要",
    "飘漂瞟",
    "径经泾",
    "斗抖科斟魁料",
    "厥橛獗",
    "方防访妨纺旅仿",
    "且阻组谊宜咀",
    "异导吼孔",
    "约钓",
    "并开",
    "导异",
    "绞跤吹炊",
    "澄橙",
    "不坏环",
    "磁滋糍慈",
    "契楔揳",
    "模洒操忙拣待佳",
    "购构狗够",
    "酉酒酥酬醉配酿",
    "汗汁",
    "探深",
    "曾增赠僧憎",
    "苟苞",
    "军浑挥晕晖辉",
    "咸减喊",
    "留榴瘤溜遛",
    "其斯期欺旗",
    "正证症政征",
    "卓齐盘宇党违惨",
    "伟违纬",
    "具惧俱",
    "部剖陪培倍赔",
    "枯姑估",
    "摊滩难准",
    "劳涝捞",
    "病功驰蔼闷险现",
    "溅贱残浅",
    "逝浙",
    "沸佛拂",
    "论沦轮伦",
    "馀涂途斜叙徐除",
    "孚俘浮",
    "寻灵雪扫",
    "皮破波坡彼被玻披疲 跛皱",
    "黑默墨黝",
    "弛驰驰",
    "厉历",
    "王斑班狂枉",
    "适怀评宪赔踩星",
    "袄妖",
    "俘浮",
    "诺若",
    "切彻砌沏",
    "付附咐驸府俯腐",
    "雪寻灵雪扫",
    "箱相湘厢想",
    "木林材村柄栖柩框沐",
    "句苟",
    "展辗碾",
    "影景",
    "讯迅汛",
    "韦伟苇纬",
    "句苟句",
    "真慎填",
    "利俐犁梨",
    "蹈稻滔韬",
    "谓猬",
    "瓜爪弧",
    "仑纶论沦伦抡轮",
    "济挤跻脐",
    "麻磨摩魔靡",
    "摩磨蘑麻",
    "稍梢哨捎",
    "乍作昨诈炸",
    "示标祭票",
    "粪乃老起龙异署",
    "今贪念妗吟",
    "喘揣端湍瑞",
    "茸耸",
    "泡饱抱炮跑",
    "抬胎苔台",
    "寺持等待诗侍特恃峙",
    "撤撒籍霜",
    "肖消梢销捎悄哨稍硝峭俏鞘睄诮帩",
    "培赔陪蓓",
    "遍狠精详轿逼葫",
    "朝潮嘲",
    "伯柏",
    "遐瑕暇假",
    "骄轿娇矫",
    "果课棵颗夥",
    "甫捕辅哺铺搏脯膊蒲敷",
    "屈掘倔",
    "揩楷锴谐偕喈",
    "篇艰请样桥福湖",
    "耳耻职联聘饵茸耸娉俜骋",
    "宵霄",
    "吐朴乘真漂植识",
    "冷领铃怜",
    "彼披破坡波",
    "媚眉搀馋",
    "灿仙",
    "卌卅",
    "宛碗婉腕蜿惋",
    "列例烈裂冽咧",
    "诈榨",
    "悔晦诲",
    "过辽疗",
    "分粉芬份纷",
    "建健毽腱键",
    "谣炉抓净狐结讨",
    "扁篇骗偏遍编",
    "吴误娱",
    "颁颔颌颀硕颐",
    "磋蹉",
    "板粗防泡彼住缝",
    "尤忧优",
    "从丛纵众枞",
    "丰峰锋烽蜂逢缝蓬",
    "居据剧",
    "页顽烦领顺须",
    "内肉",
    "喝渴蔼",
    "寺诗侍峙持待",
    "寺持等待诗侍特 恃 峙",
    "录碌绿逮剥",
    "留溜榴榴",
    "风枫疯凤讽",
    "请清情晴精睛",
    "需儒孺濡",
    "灰诙恢碳炭",
    "固涸",
    "旦担坦",
    "湛勘斟堪",
    "临监鉴篮蓝滥槛",
    "诀决快块缺",
    "伐代",
    "苗描猫瞄",
    "格骆络",
    "争筝铮峥挣诤狰净静",
    "捆困团闲",
    "篙缟槁蒿镐嵩",
    "称状糖袄掩仗因",
    "贝见",
    "彦颜谚",
    "樱婴鹦",
    "容溶榕",
    "绊拌",
    "办苏协胁",
    "麻磨摩魔靡糜",
    "危跪桅诡脆",
    "类粪",
    "肉缸戏咽理张蝇",
    "很银限艰根跟狠",
    "茵菌",
    "户庐炉房妒驴",
    "非菲霏排悲匪辈徘",
    "磬罄謦",
    "延诞蜒",
    "今令邻领翎冷拎玲铃伶怜",
    "朗郎踉粮",
    "拔拨托拖",
    "寿涛祷踌筹铸",
    "缴激邀",
    "势执挚",
    "样洋鲜祥详",
    "杏否",
    "非韭徘辈悲斐裴靠扉霏菲匪蜚排",
    "夹狭峡挟侠荚颊",
    "僵疆",
    "奇骑寄倚绮椅",
    "才财材",
    "誉眷誊举",
    "御卸",
    "暇假霞瑕遐",
    "视砚现",
    "宿缩",
    "正证征歪焉惩症",
    "摇遥瑶谣",
    "虎虚虑虔",
    "岛管冒茵作思涛",
    "耳耻职联聘饵茸耸",
    "吕铝宫",
    "住注往柱驻",
    "参惨渗掺",
    "支枝肢",
    "腮思崽筛",
    "难滩难摊",
    "葵擦察祭",
    "嫌谦歉廉",
    "巨矩柜拒距",
    "亡芒茫忙盲氓",
    "辨扒喂究传烂讯",
    "稳隐",
    "痛劝池喝闻捡视",
    "座夸痛援浑原则",
    "高稿搞",
    "茶荼",
    "繁敏",
    "沾贴砖帖",
    "青清晴情晴静睛精猜靓靛倩靓",
    "登凳橙蹬 澄",
    "弟第递梯剃涕",
    "各骆路洛络",
    "阡迁歼奸",
    "半伴拌绊叛判",
    "章障彰獐子",
    "勺趵钓约的灼",
    "度渡镀席",
    "池地驰",
    "朝潮嘲澈撤辙",
    "绳蝇",
    "膺赝",
    "介价阶",
    "客容",
    "曹糟嘈遭槽",
    "献现",
    "兼歉赚嫌谦廉",
    "贵溃遗",
    "暑署",
    "由迪笛油邮抽袖柚庙",
    "镶壤攘嚷",
    "输暖载栽",
    "寿涛祷踌筹铸畴俦",
    "浑辉挥晖",
    "守宇字",
    "谨勤幻幼",
    "容融溶榕",
    "魏巍翼冀",
    "部陪倍",
    "元远完玩园",
    "沁泌",
    "龙拢笼庞宠茏垄",
    "裸颗棵课",
    "贩阻妨跑波驻蜂",
    "竟镜境",
    "燥操躁澡噪藻",
    "徂狙沮咀龃趄诅俎租",
    "左在",
    "干于",
    "虚虑虎",
    "从丛纵众",
    "石朗层见柏仙景",
    "晤悟",
    "忙芒茫",
    "侮悔诲晦",
    "测侧则",
    "仓沧苍伧枪抢",
    "雨霎雾雷雪霜霆雹",
    "祥详翔样",
    "旱捍悍",
    "复履覆",
    "卜补扑仆朴赴",
    "捷睫",
    "包饱泡抱炮袍",
    "邗邛顼顸",
    "溶熔",
    "此柴紫些",
    "易惕踢剔锡赐",
    "柝坼祗诋邸柢砥抵抵泜胝",
    "织识职",
    "捡脸险",
    "吹炊饮欢",
    "夭袄沃跃妖",
    "立拉垃站粒泣笠",
    "秋愁",
    "罐灌罐",
    "正证征歪焉惩症状",
    "刑型荆形",
    "垂锤睡陲",
    "怯劫讪仙",
    "瑰鬼",
    "并拼并饼迸",
    "做快通爱辉愿测",
    "欠炊吹坎",
    "乔骄桥轿娇侨矫",
    "朋棚鹏",
    "引张",
    "余涂途斜叙徐除",
    "斤折拆析近浙哲晰",
    "椽喙蠡掾缘",
    "据剧居踞",
    "坚竖",
    "麻脏慢苟虎汗茸",
    "干秆杆轩",
    "籍藉",
    "我峨娥",
    "碍得泣拉",
    "勃脖",
    "京惊凉晾谅掠",
    "厮撕",
    "帝蹄啼",
    "召招照沼",
    "羽翔翩翘翻翅翱",
    "委萎",
    "叨叼刀刁",
    "敬警擎儆",
    "岛鸟",
    "息熄",
    "欠炊吹欢饮坎",
    "召诏招昭沼",
    "挂桂洼封卦娃蛙佳哇",
    "亥该核咳刻",
    "每海诲悔霉晦梅侮",
    "扒趴叭",
    "累骡螺摞",
    "胡糊蝴湖",
    "龌龊龃龉",
    "弗沸拂佛",
    "急稳隐瘾",
    "刮乱",
    "流之抹分梅惊胆",
    "齐济挤剂跻",
    "奉棒捧",
    "涨胀张",
    "住维推堆准",
    "景影",
    "烂栏拦兰",
    "辉挥浑",
    "豪毫",
    "云芸动运耘",
    "乃仍奶及吸极级扔",
    "令怜伶邻冷领龄铃岭玲拎",
    "婵蝉箪殚掸惮禅",
    "标际示",
    "尊遵蹲樽",
    "鱼鳅鲜鳍鲸鲇",
    "胡湖蝴糊",
    "操躁澡",
    "框筐眶狂",
    "浩结洁吉",
    "炉庐",
    "脾卑碑啤",
    "仗杖",
    "废疲",
    "驿泽择译",
    "滩帖捕盯吭宙档",
    "痛疼病",
    "援暖缓",
    "力历沥枥厉励砺",
    "参惨渗",
    "扳组仿炮坡柱烽",
    "刑型",
    "埋理",
    "盲肓",
    "抚芜拴栓",
    "铛档挡当",
    "参掺惨渗",
    "奂焕涣换焕",
    "广旷矿",
    "朱株珠",
    "哥歌鬲隔融嗝",
    "妥要耍",
    "辛瓣辩辫辨辞辟避宰辣",
    "汛迅讯",
    "搏博傅薄礴缚",
    "帝啼谛缔蒂蹄",
    "即既颇须榜傍磅膀",
    "渴竭碣谒",
    "米继断眯迷",
    "奇绮畸崎椅倚",
    "摊滩难瘫",
    "淄缁辎锱",
    "摇谣遥瑶",
    "订盯钉叮",
    "苍沧抢枪",
    "赏堂党裳掌撑棠常",
    "童幢憧撞",
    "仰昂迎抑",
    "鬲隔融嗝",
    "锦棉绵帛",
    "浦捕哺铺",
    "需懦儒",
    "永泳咏",
    "哀衰蓑猿",
    "疲努促调灾奋并",
    "右郎屋贝伯灿影",
    "译择泽驿绎",
    "舀稻蹈",
    "刃忍仞",
    "开形刑型",
    "象像橡",
    "鸟岛鸣莺鹅鹊鹤",
    "东冻栋",
    "羊详样洋鲜群",
    "栗乱搭宝师曾奠",
    "湖糊蝴瑚葫",
    "敝蔽憋鳖弊",
    "摇护爪挣孤洁付",
    "岷泯眠民",
    "留溜流瘤",
    "至侄窒倒到致",
    "上止址让企扯肯",
    "占钻贴粘",
    "键健",
    "蓝篮监临",
    "枯题榆过顽极格",
    "甚堪斟勘湛戡椹",
    "蹇搴褰骞",
    "共洪拱哄",
    "操燥躁澡",
    "慌谎荒流",
    "创枪",
    "烧浇挠",
    "郊蛟跤绞",
    "圭蛙娃洼桂挂佳涯崖封畦",
    "宠庞笼拢",
    "俞愉输愈榆喻偷瑜",
    "辨辩瓣",
    "耽眈忱枕",
    "恰洽",
    "尉慰蔚熨",
    "次资咨姿",
    "青清晴睛蜻猜情倩",
    "串患窜",
    "及级极汲吸圾",
    "皿盐监盆盒孟猛盂",
    "梯弟涕递挨埃唉",
    "谮僭",
    "会侩脍",
    "尤龙",
    "遥摇瑶谣",
    "身射躲",
    "鬼槐愧魂魄魔",
    "陨损协胁",
    "炉庐护",
    "卑脾牌碑",
    "康糠慷",
    "紫紧",
    "寸守付衬村时对过讨",
    "话环苹冼陪菜湿",
    "申审伸呻",
    "某谋媒煤",
    "愿源原",
    "遗匮馈遣",
    "陡徒",
    "肄肆",
    "赛塞寒",
    "奋备",
    "罗萝逻锣箩",
    "烩荟桧侩刽",
    "朝潮嘲瀚",
    "支枝技歧鼓肢岐山",
    "少沙吵抄炒妙纱",
    "棍混堤提",
    "嶙粼磷麟鳞",
    "奋备思佃亩",
    "哺捕辅甫",
    "佳挂桂",
    "兆跳眺挑桃逃佻",
    "乏泛眨",
    "洎汨汩",
    "塔搭",
    "肚扑乖具飘值织",
    "努怒",
    "睁挣筝争",
    "丞承",
    "亡忙芒虻",
    "皮破波坡彼被玻披疲跛皱",
    "央秧殃泱",
    "钮羞扭丑",
    "忙茫芒氓",
    "盐盆盒孟猛盂",
    "撩嘹潦了燎镣",
    "快块夸",
    "几讥凯饥肌",
    "疼动地渴问脸砚",
    "梁粱渠喋",
    "肖消梢销捎悄哨稍硝",
    "容蓉熔溶榕",
    "旬询殉",
    "林婪楚梦禁",
    "控腔",
    "娄楼搂数缕偻褛蒌",
    "丑扭钮纽",
    "辟避璧譬僻臂壁劈",
    "崇祟",
    "幅副逼福",
    "疒瘦病疗疼痒",
    "蒙檬朦曚",
    "前煎剪",
    "廷廷挺庭霆艇蜓",
    "践贱线钱笺残浅",
    "原源愿",
    "只识织职枳帜",
    "辟避癖劈壁璧",
    "氏纸低底抵",
    "#同形字，\"\\t\"间隔",
    "庆厌",
    "乖乘剩",
    "高篙稿搞缟"
]


hanzi = "啊阿埃挨哎唉哀皑癌蔼矮艾碍爱隘鞍氨安俺按暗岸胺案肮昂盎凹敖熬翱袄傲奥懊澳芭捌扒叭吧笆八疤巴拔跋靶把耙坝霸罢爸白柏百摆佰败拜稗斑班搬扳般颁板版扮拌伴瓣半办绊邦帮梆榜膀绑棒磅蚌镑傍谤苞胞包褒剥薄雹保堡饱宝抱报暴豹鲍爆杯碑悲卑北辈背贝钡倍狈备惫焙被奔苯本笨崩绷甭泵蹦迸逼鼻比鄙笔彼碧蓖蔽毕毙毖币庇痹闭敝弊必辟壁臂避陛鞭边编贬扁便变卞辨辩辫遍标彪膘表鳖憋别瘪彬斌濒滨宾摈兵冰柄丙秉饼炳病并玻菠播拨钵波博勃搏铂箔伯帛舶脖膊渤泊驳捕卜哺补埠不布步簿部怖擦猜裁材才财睬踩采彩菜蔡餐参蚕残惭惨灿苍舱仓沧藏操糙槽曹草厕策侧册测层蹭插叉茬茶查碴搽察岔差诧拆柴豺搀掺蝉馋谗缠铲产阐颤昌猖场尝常长偿肠厂敞畅唱倡超抄钞朝嘲潮巢吵炒车扯撤掣彻澈郴臣辰尘晨忱沉陈趁衬撑称城橙成呈乘程惩澄诚承逞骋秤吃痴持匙池迟弛驰耻齿侈尺赤翅斥炽充冲虫崇宠抽酬畴踌稠愁筹仇绸瞅丑臭初出橱厨躇锄雏滁除楚础储矗搐触处揣川穿椽传船喘串疮窗幢床闯创吹炊捶锤垂春椿醇唇淳纯蠢戳绰疵茨磁雌辞慈瓷词此刺赐次聪葱囱匆从丛凑粗醋簇促蹿篡窜摧崔催脆瘁粹淬翠村存寸磋撮搓措挫错搭达答瘩打大呆歹傣戴带殆代贷袋待逮怠耽担丹单郸掸胆旦氮但惮淡诞弹蛋当挡党荡档刀捣蹈倒岛祷导到稻悼道盗德得的蹬灯登等瞪凳邓堤低滴迪敌笛狄涤翟嫡抵底地蒂第帝弟递缔颠掂滇碘点典靛垫电佃甸店惦奠淀殿碉叼雕凋刁掉吊钓调跌爹碟蝶迭谍叠丁盯叮钉顶鼎锭定订丢东冬董懂动栋侗恫冻洞兜抖斗陡豆逗痘都督毒犊独读堵睹赌杜镀肚度渡妒端短锻段断缎堆兑队对墩吨蹲敦顿囤钝盾遁掇哆多夺垛躲朵跺舵剁惰堕蛾峨鹅俄额讹娥恶厄扼遏鄂饿恩而儿耳尔饵洱二贰发罚筏伐乏阀法珐藩帆番翻樊矾钒繁凡烦反返范贩犯饭泛坊芳方肪房防妨仿访纺放菲非啡飞肥匪诽吠肺废沸费芬酚吩氛分纷坟焚汾粉奋份忿愤粪丰封枫蜂峰锋风疯烽逢冯缝讽奉凤佛否夫敷肤孵扶拂辐幅氟符伏俘服浮涪福袱弗甫抚辅俯釜斧脯腑府腐赴副覆赋复傅付阜父腹负富讣附妇缚咐噶嘎该改概钙盖溉干甘杆柑竿肝赶感秆敢赣冈刚钢缸肛纲岗港杠篙皋高膏羔糕搞镐稿告哥歌搁戈鸽胳疙割革葛格蛤阁隔铬个各给根跟耕更庚羹埂耿梗工攻功恭龚供躬公宫弓巩汞拱贡共钩勾沟苟狗垢构购够辜菇咕箍估沽孤姑鼓古蛊骨谷股故顾固雇刮瓜剐寡挂褂乖拐怪棺关官冠观管馆罐惯灌贯光广逛瑰规圭硅归龟闺轨鬼诡癸桂柜跪贵刽辊滚棍锅郭国果裹过哈骸孩海氦亥害骇酣憨邯韩含涵寒函喊罕翰撼捍旱憾悍焊汗汉夯杭航壕嚎豪毫郝好耗号浩呵喝荷菏核禾和何合盒貉阂河涸赫褐鹤贺嘿黑痕很狠恨哼亨横衡恒轰哄烘虹鸿洪宏弘红喉侯猴吼厚候后呼乎忽瑚壶葫胡蝴狐糊湖弧虎唬护互沪户花哗华猾滑画划化话槐徊怀淮坏欢环桓还缓换患唤痪豢焕涣宦幻荒慌黄磺蝗簧皇凰惶煌晃幌恍谎灰挥辉徽恢蛔回毁悔慧卉惠晦贿秽会烩汇讳诲绘荤昏婚魂浑混豁活伙火获或惑霍货祸击圾基机畸稽积箕肌饥迹激讥鸡姬绩缉吉极棘辑籍集及急疾汲即嫉级挤几脊己蓟技冀季伎祭剂悸济寄寂计记既忌际妓继纪嘉枷夹佳家加荚颊贾甲钾假稼价架驾嫁歼监坚尖笺间煎兼肩艰奸缄茧检柬碱碱拣捡简俭剪减荐槛鉴践贱见键箭件健舰剑饯渐溅涧建僵姜将浆江疆蒋桨奖讲匠酱降蕉椒礁焦胶交郊浇骄娇嚼搅铰矫侥脚狡角饺缴绞剿教酵轿较叫窖揭接皆秸街阶截劫节桔杰捷睫竭洁结解姐戒藉芥界借介疥诫届巾筋斤金今津襟紧锦仅谨进靳晋禁近烬浸尽劲荆兢茎睛晶鲸京惊精粳经井警景颈静境敬镜径痉靖竟竞净炯窘揪究纠玖韭久灸九酒厩救旧臼舅咎就疚鞠拘狙疽居驹菊局咀矩举沮聚拒据巨具距踞锯俱句惧炬剧捐鹃娟倦眷卷绢撅攫抉掘倔爵觉决诀绝均菌钧军君峻俊竣浚郡骏喀咖卡咯开揩楷凯慨刊堪勘坎砍看康慷糠扛抗亢炕考拷烤靠坷苛柯棵磕颗科壳咳可渴克刻客课肯啃垦恳坑吭空恐孔控抠口扣寇枯哭窟苦酷库裤夸垮挎跨胯块筷侩快宽款匡筐狂框矿眶旷况亏盔岿窥葵奎魁傀馈愧溃坤昆捆困括扩廓阔垃拉喇蜡腊辣啦莱来赖蓝婪栏拦篮阑兰澜谰揽览懒缆烂滥琅榔狼廊郎朗浪捞劳牢老佬姥酪烙涝勒乐雷镭蕾磊累儡垒擂肋类泪棱楞冷厘梨犁黎篱狸离漓理李里鲤礼莉荔吏栗丽厉励砾历利僳例俐痢立粒沥隶力璃哩俩联莲连镰廉怜涟帘敛脸链恋炼练粮凉梁粱良两辆量晾亮谅撩聊僚疗燎寥辽潦了撂镣廖料列裂烈劣猎琳林磷霖临邻鳞淋凛赁吝拎玲菱零龄铃伶羚凌灵陵岭领另令溜琉榴硫馏留刘瘤流柳六龙聋咙笼窿隆垄拢陇楼娄搂篓漏陋芦卢颅庐炉掳卤虏鲁麓碌露路赂鹿潞禄录陆戮驴吕铝侣旅履屡缕虑氯律率滤绿峦挛孪滦卵乱掠略抡轮伦仑沦纶论萝螺罗逻锣箩骡裸落洛骆络妈麻玛码蚂马骂嘛吗埋买麦卖迈脉瞒馒蛮满蔓曼慢漫谩芒茫盲氓忙莽猫茅锚毛矛铆卯茂冒帽貌贸么玫枚梅酶霉煤没眉媒镁每美昧寐妹媚门闷们萌蒙檬盟锰猛梦孟眯醚靡糜迷谜弥米秘觅泌蜜密幂棉眠绵冕免勉娩缅面苗描瞄藐秒渺庙妙蔑灭民抿皿敏悯闽明螟鸣铭名命谬摸摹蘑模膜磨摩魔抹末莫墨默沫漠寞陌谋牟某拇牡亩姆母墓暮幕募慕木目睦牧穆拿哪呐钠那娜纳氖乃奶耐奈南男难囊挠脑恼闹淖呢馁内嫩能妮霓倪泥尼拟你匿腻逆溺蔫拈年碾撵捻念娘酿鸟尿捏聂孽啮镊镍涅您柠狞凝宁拧泞牛扭钮纽脓浓农弄奴努怒女暖虐疟挪懦糯诺哦欧鸥殴藕呕偶沤啪趴爬帕怕琶拍排牌徘湃派攀潘盘磐盼畔判叛乓庞旁耪胖抛咆刨炮袍跑泡呸胚培裴赔陪配佩沛喷盆砰抨烹澎彭蓬棚硼篷膨朋鹏捧碰坯砒霹批披劈琵毗啤脾疲皮匹痞僻屁譬篇偏片骗飘漂瓢票撇瞥拼频贫品聘乒坪苹萍平凭瓶评屏坡泼颇婆破魄迫粕剖扑铺仆莆葡菩蒲埔朴圃普浦谱曝瀑期欺栖戚妻七凄漆柒沏其棋奇歧畦崎脐齐旗祈祁骑起岂乞企启契砌器气迄弃汽泣讫掐洽牵扦钎铅千迁签仟谦乾黔钱钳前潜遣浅谴堑嵌欠歉枪呛腔羌墙蔷强抢橇锹敲悄桥瞧乔侨巧鞘撬翘峭俏窍切茄且怯窃钦侵亲秦琴勤芹擒禽寝沁青轻氢倾卿清擎晴氰情顷请庆琼穷秋丘邱球求囚酋泅趋区蛆曲躯屈驱渠取娶龋趣去圈颧权醛泉全痊拳犬券劝缺炔瘸却鹊榷确雀裙群然燃冉染瓤壤攘嚷让饶扰绕惹热壬仁人忍韧任认刃妊纫扔仍日戎茸蓉荣融熔溶容绒冗揉柔肉茹蠕儒孺如辱乳汝入褥软阮蕊瑞锐闰润若弱撒洒萨腮鳃塞赛三叁伞散桑嗓丧搔骚扫嫂瑟色涩森僧莎砂杀刹沙纱傻啥煞筛晒珊苫杉山删煽衫闪陕擅赡膳善汕扇缮墒伤商赏晌上尚裳梢捎稍烧芍勺韶少哨邵绍奢赊蛇舌舍赦摄射慑涉社设砷申呻伸身深娠绅神沈审婶甚肾慎渗声生甥牲升绳省盛剩胜圣师失狮施湿诗尸虱十石拾时什食蚀实识史矢使屎驶始式示士世柿事拭誓逝势是嗜噬适仕侍释饰氏市恃室视试收手首守寿授售受瘦兽蔬枢梳殊抒输叔舒淑疏书赎孰熟薯暑曙署蜀黍鼠属术述树束戍竖墅庶数漱恕刷耍摔衰甩帅栓拴霜双爽谁水睡税吮瞬顺舜说硕朔烁斯撕嘶思私司丝死肆寺嗣四伺似饲巳松耸怂颂送宋讼诵搜艘擞嗽苏酥俗素速粟僳塑溯宿诉肃酸蒜算虽隋随绥髓碎岁穗遂隧祟孙损笋蓑梭唆缩琐索锁所塌他它她塔獭挞蹋踏胎苔抬台泰酞太态汰坍摊贪瘫滩坛檀痰潭谭谈坦毯袒碳探叹炭汤塘搪堂棠膛唐糖倘躺淌趟烫掏涛滔绦萄桃逃淘陶讨套特藤腾疼誊梯剔踢锑提题蹄啼体替嚏惕涕剃屉天添填田甜恬舔腆挑条迢眺跳贴铁帖厅听烃汀廷停亭庭挺艇通桐酮瞳同铜彤童桶捅筒统痛偷投头透凸秃突图徒途涂屠土吐兔湍团推颓腿蜕褪退吞屯臀拖托脱鸵陀驮驼椭妥拓唾挖哇蛙洼娃瓦袜歪外豌弯湾玩顽丸烷完碗挽晚皖惋宛婉万腕汪王亡枉网往旺望忘妄威巍微危韦违桅围唯惟为潍维苇萎委伟伪尾纬未蔚味畏胃喂魏位渭谓尉慰卫瘟温蚊文闻纹吻稳紊问嗡翁瓮挝蜗涡窝我斡卧握沃巫呜钨乌污诬屋无芜梧吾吴毋武五捂午舞伍侮坞戊雾晤物勿务悟误昔熙析西硒矽晰嘻吸锡牺稀息希悉膝夕惜熄烯溪汐犀檄袭席习媳喜铣洗系隙戏细瞎虾匣霞辖暇峡侠狭下厦夏吓掀锨先仙鲜纤咸贤衔舷闲涎弦嫌显险现献县腺馅羡宪陷限线相厢镶香箱襄湘乡翔祥详想响享项巷橡像向象萧硝霄削哮嚣销消宵淆晓小孝校肖啸笑效楔些歇蝎鞋协挟携邪斜胁谐写械卸蟹懈泄泻谢屑薪芯锌欣辛新忻心信衅星腥猩惺兴刑型形邢行醒幸杏性姓兄凶胸匈汹雄熊休修羞朽嗅锈秀袖绣墟戌需虚嘘须徐许蓄酗叙旭序畜恤絮婿绪续轩喧宣悬旋玄选癣眩绚靴薛学穴雪血勋熏循旬询寻驯巡殉汛训讯逊迅压押鸦鸭呀丫芽牙蚜崖衙涯雅哑亚讶焉咽阉烟淹盐严研蜒岩延言颜阎炎沿奄掩眼衍演艳堰燕厌砚雁唁彦焰宴谚验殃央鸯秧杨扬佯疡羊洋阳氧仰痒养样漾邀腰妖瑶摇尧遥窑谣姚咬舀药要耀椰噎耶爷野冶也页掖业叶曳腋夜液一壹医揖铱依伊衣颐夷遗移仪胰疑沂宜姨彝椅蚁倚已乙矣以艺抑易邑屹亿役臆逸肄疫亦裔意毅忆义益溢诣议谊译异翼翌绎茵荫因殷音阴姻吟银淫寅饮尹引隐印英樱婴鹰应缨莹萤营荧蝇迎赢盈影颖硬映哟拥佣臃痈庸雍踊蛹咏泳涌永恿勇用幽优悠忧尤由邮铀犹油游酉有友右佑釉诱又幼迂淤于盂榆虞愚舆余俞逾鱼愉渝渔隅予娱雨与屿禹宇语羽玉域芋郁吁遇喻峪御愈欲狱育誉浴寓裕预豫驭鸳渊冤元垣袁原援辕园员圆猿源缘远苑愿怨院曰约越跃钥岳粤月悦阅耘云郧匀陨允运蕴酝晕韵孕匝砸杂栽哉灾宰载再在咱攒暂赞赃脏葬遭糟凿藻枣早澡蚤躁噪造皂灶燥责择则泽贼怎增憎曾赠扎喳渣札轧铡闸眨栅榨咋乍炸诈摘斋宅窄债寨瞻毡詹粘沾盏斩辗崭展蘸栈占战站湛绽樟章彰漳张掌涨杖丈帐账仗胀瘴障招昭找沼赵照罩兆肇召遮折哲蛰辙者锗蔗这浙珍斟真甄砧臻贞针侦枕疹诊震振镇阵蒸挣睁征狰争怔整拯正政帧症郑证芝枝支吱蜘知肢脂汁之织职直植殖执值侄址指止趾只旨纸志挚掷至致置帜峙制智秩稚质炙痔滞治窒中盅忠钟衷终种肿重仲众舟周州洲诌粥轴肘帚咒皱宙昼骤珠株蛛朱猪诸诛逐竹烛煮拄瞩嘱主著柱助蛀贮铸筑住注祝驻抓爪拽专砖转撰赚篆桩庄装妆撞壮状椎锥追赘坠缀谆准捉拙卓桌琢茁酌啄着灼浊兹咨资姿滋淄孜紫仔籽滓子自渍字鬃棕踪宗综总纵邹走奏揍租足卒族祖诅阻组钻纂嘴醉最罪尊遵昨左佐柞做作坐座"


import jieba
from fairies import stop_words

stop_words = stop_words.stop_words


def jieba_init():
    
    """
        初始化jieba分词字典 提前加载,不会在调用时再加载
    """
    
    jieba.initialize()

def jieba_cut(text):
    
    """
        jieba分词普通模式
        传入text 返回list
    """
    res = []
    seg_list = jieba.cut(text, cut_all=False)
    for i in seg_list:
        res.append(i)

    return res    

def jieba_add_words(lists):
    for i in lists:
        jieba.suggest_freq(i, True)


def find_co_occurrence_word(texts,nums = 10):

    """
        texts 切分的文本列表
        nums 关键词数量 默认为10
    """

    res = {}
    for text in texts:
        word_lists = jieba_cut(text)
        for word in word_lists:
            if word not in stop_words and len(word) > 1:
                if word not in res:
                    res[word] = 1
                else:
                    res[word] += 1

    res = sorted(res.items(),key=lambda item:item[1],reverse = True)

    pos = []
    for i in res[:nums]:
        pos.append(i[0])

    count = 0
    for text in texts:
        for n in pos:
            if n in text:
                count += 1
                break
    
    print('关键词列表',pos)
    print('覆盖率',count/len(texts))        
    
    return pos


import xlrd
import xlwt
from xlutils.copy import copy

def read_excel(fileName,table_name):
    # rowNum = table.nrows
    # colNum = table.ncols
    # 使用table.cell(i,0).value 调用
    data = xlrd.open_workbook(fileName)
    table = data.sheet_by_name(table_name)
    return table


def write_excel(fileName,sheet_num = 0):

    """
        通过worksheet写入excel的值
        处理后的excel，
        使用excel.save("final.xls")保存
    
    """

    data = xlrd.open_workbook(fileName)
    excel = copy(data)  # 将xlrd的对象转化为xlwt的对象
    worksheet = excel.get_sheet(sheet_num)  # 获取要操作的sheet
    
    return excel,worksheet


import re
import jieba
import random
import datetime

def isMask(text):
    
    # 判断该字符是否是标点符号
    mask_list = ["。","！","…","？","?","!","；",";","，"]
    if text in mask_list:
        return True
    else:
        return False   

def isHasMark(text):
    
    # 判断文本中是否有符号
    marks = ['。','！','…','？','?','!','；',';','，']

    for i in marks:
        if i in text:
            return True

    return False

def label2id(labels):
    """
    return: id2label,label2id 
    """

    id2label = dict(enumerate(labels))
    label2id = {j: i for i, j in id2label.items()}
    return id2label,label2id      

def is_chinese(string):
    """
    检查整个字符串是否包含中文
    :param string: 需要检查的字符串
    :return: bool
    """
    for ch in string:
        if u'\u4e00' <= ch <= u'\u9fff':
            return True

    return False

def find_lcs(s1, s2):
    """find the longest common subsequence between s1 ans s2"""
    """公共子串"""
    m = [[0 for i in range(len(s2)+1)] for j in range(len(s1)+1)]
    max_len = 0
    p = 0
    for i in range(len(s1)):
        for j in range(len(s2)):
            if s1[i] == s2[j]:
                m[i+1][j+1] = m[i][j]+1
                if m[i+1][j+1] > max_len:
                    max_len = m[i+1][j+1]
                    p = i+1
    return s1[p-max_len:p], max_len    

def random_build_data(all_data,percent):
    
    """
        检查整个字符串是否包含中文
        :param all_data: list 全部数据
        :param percent: int 按照1：percent分配train_data和dev_data
                        0.9 代表train_data和dev_data 比例 9:1
        :return: train_data,dev_data
    """
    random.shuffle(all_data)

    if percent < 1:
        percent = int(1/(1-percent))
        if percent > 1:
            percent -= 1

    train_data = [d for i, d in enumerate(all_data) if i %percent != 0]
    dev_data = [d for i, d in enumerate(all_data) if i %percent == 0]

    return train_data,dev_data

def get_data_information(): 

    """
        获得时间信息
    """

    cur=datetime.datetime.now()
    day = cur.day
    month = cur.month
    return day + '_' + month


def long_substr(data):
    
    """
        输入数组,输出多个字符传的公共子串
    """
    
    substr = ''
    if len(data) > 1 and len(data[0]) > 0:
        for i in range(len(data[0])):
            for j in range(len(data[0])-i+1):
                if j > len(substr) and is_substr(data[0][i:i+j], data):
                    substr = data[0][i:i+j]
    return substr

def is_substr(find, data):
    if len(data) < 1 and len(find) < 1:
        return False
    for i in range(len(data)):
        if find not in data[i]:
            return False
    return True        


import re
from fairies.langconv import *

def clean_data(text):

    temp = ['\uf043','\uf020','\uf076','\uf046','\uf075','\uf06c','\uf09f','\uf0d8','\uf072','\uf077','．','…','„',' ']
    List = re.findall(r'[(]cid.*?[)]',text)
    List = List + temp
    for l in List:
        text = text.replace(l,'')
    text = removeLineFeed(text)
    return text            

def removeLineFeed(text):
    
    """去除换行 tab键"""
    k = text.replace('\r','').replace('\n','').replace('\t',' ')
    return k

def cht_2_chs(line):
    line = Converter('zh-hans').convert(line)
    line.encode('utf-8')
    return line

# 转换简体到繁体
def chs_2_cht(sentence):
    sentence = Converter('zh-hant').convert(sentence)
    return sentence

def strQ2B(ustring):
    """全角转半角"""
    rstring = ""
    for uchar in ustring:
        inside_code=ord(uchar)
        if inside_code == 12288:                              #全角空格直接转换
            inside_code = 32
        elif (inside_code >= 65281 and inside_code <= 65374): #全角字符（除空格）根据关系转化
            inside_code -= 65248

        rstring += chr(inside_code)
    return rstring    


import json
import os
import requests
import zipfile
import pandas as pd
import codecs

def write_json(filename,res,isIndent = True):
    
    if isIndent:
        json_str = json.dumps(res,ensure_ascii=False,indent=4)
        with open(filename, 'w',encoding = 'utf-8') as json_file:
            json_file.write(json_str)
    else:        
        with codecs.open(filename, 'w', 'utf-8') as f:
            for formatted_instance in res:
                json_str = json.dumps(formatted_instance, ensure_ascii=False)
                f.write(json_str)
                f.write('\n')
        f.close()

def read_json(filename):
    try:
        with open(filename,'r',encoding='utf8') as f:
            json_data = json.load(f)
    except:
        json_data = []
        with open(filename,encoding='utf-8') as f:
            for line in f:
                json_data.append(json.loads(line))        
    return json_data

def write_txt(fileName,lists,model = 'normal'):

    """
        按行写入
    """
    if model == 'normal':
        f = open(fileName,'w',encoding='utf8')
    else:    
        f = open(fileName, 'a',encoding='utf8')
    for i in lists:
        f.write(str(i))
        f.write('\n')
    f.close()

def read_txt(fileName):

    """
        读取txt文件
    """

    res = []
    file = open(fileName,encoding='utf8') 
    lines = file.readlines(100000)
    for line in lines:
        res.append(line)

    file.close()
    return res

def reSort(filename,isReverse = True):
    
    """
        对字典或数组重新排序,
        isReverse 默认为true 默认越长的元素排在前面 为False 相反 
    """
    
    a = read_json(filename)
    a.sort(key=lambda a: len(a),reverse = isReverse)
    write_json(filename,a)

def get_file_size(fileName):
    # 获取文件大小
    return os.path.getsize(fileName)

def get_file_list(file_path):
    # 获取文件列表
    return os.listdir(file_path)

def download_pdf(fileName):
    # 下载pdf
    requests_pdf_url = fileName
    r = requests.get(requests_pdf_url)
    filename = fileName.replace('http://','').replace('/','')
    with open(filename, 'wb+') as f:
        f.write(r.content)

def unzip_file(zip_src, dst_dir):
       
    """
        解压文件
    """
    r = zipfile.is_zipfile(zip_src)
    if r:     
        fz = zipfile.ZipFile(zip_src, 'r')
        for file in fz.namelist():
            fz.extract(file, dst_dir)       
    else:
        print('This is not zip')

def an_garcode(dir_names):

    """anti garbled code"""
    os.chdir(dir_names)

    for temp_name in os.listdir('.'):
        try:
            #使用cp437对文件名进行解码还原
            new_name = temp_name.encode('cp437')
            #win下一般使用的是gbk编码
            new_name = new_name.decode("gbk")
            #对乱码的文件名及文件夹名进行重命名
            os.rename(temp_name, new_name)
            #传回重新编码的文件名给原文件名
            temp_name = new_name
        except:
            #如果已被正确识别为utf8编码时则不需再编码
            pass      

def get_listdir(path):
    
    """
        得到文件下路径
    """

    res = []
    a = os.listdir(path)
    for i in a:
        k = os.path.join(path,i)
        res.append(k)

    return res   


import re
import json
from io import StringIO
from io import open
from pdfminer.converter import TextConverter
from pdfminer.layout import LAParams
from pdfminer.pdfinterp import PDFResourceManager, process_pdf
from pdfminer.pdfparser import PDFParser, PDFDocument
from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
from pdfminer.converter import PDFPageAggregator
from pdfminer.layout import LAParams, LTTextBox
from pdfminer.pdfinterp import PDFTextExtractionNotAllowed
import os
from fairies.nlp_clean_data import clean_data
from fairies.nlp_utils import isHasMark
from fairies.nlp_data_processing import split_to_sents
from fairies.nlp_clean_data import removeLineFeed
from bs4 import BeautifulSoup
from fairies import prefix

prefix_list = prefix.prefix

def isHasPrefix(text):

    for i in prefix_list:
        if i in text:
            return True
    return False   

def read_pdf_by_line(filename):

    """
    read pdf by line

    """
    with open(filename, "rb") as pdf:
            rsrcmgr = PDFResourceManager()
            retstr = StringIO()
            laparams = LAParams()
            device = TextConverter(rsrcmgr, retstr, laparams=laparams)
            process_pdf(rsrcmgr, device, pdf)
            device.close()
            content = retstr.getvalue()
            retstr.close()
            lines = str(content).split("\n")
    return lines

def read_pdf_by_box(pdf):

    praser = PDFParser(open(pdf, 'rb'))
    doc = PDFDocument()
    praser.set_document(doc)
    doc.set_parser(praser)

    doc.initialize()

    if not doc.is_extractable:
        return []
    else:

        rsrcmgr = PDFResourceManager()
        laparams = LAParams()
        device = PDFPageAggregator(rsrcmgr, laparams=laparams)
        interpreter = PDFPageInterpreter(rsrcmgr, device)

        res = []
        nums = ['0','1','2','3','4','5','6','7','8','9','10','11','12','13','14']

        for page in doc.get_pages():

            interpreter.process_page(page)                        
            layout = device.get_result()
            
            temp_label = ''   # 段落标签
            is_merge = False  # 针对pdf的分页

            for x in layout:
                if isinstance(x, LTTextBox):

                    text = x.get_text().strip()

                    if text in nums:
                        is_merge = True
                        continue
                    # print(text)
                    if len(text) < 2:
                        continue
                    
                    if is_merge :
                        is_merge = False
                        if len(res) > 0:
                            res[-1][1] = res[-1][1] + clean_data(text) 
                        temp_label = ''
                        continue

                    if text[0] in nums and text[1] == '.':
                        start = 1
                        for i in range(1,len(text)-1):
                            if text[i] in nums or text[i] == '.':
                                start = i  
                            else:
                                break
                        temp_label = ''
                        text = text[start+1:]   
                    
                    if text == '':
                        continue

                    if len(text) < 18 and not isHasMark(text):

                        temp_label = text

                    if '    ' in text:
                        s = text.find('     ')
                        temp_label = text[:s]

                        text = text[s:]

                    if len(text) > 18 or text[-1] == '。':
                        temp_label = clean_data(temp_label)
                        text = clean_data(text)

                        if isHasMark(temp_label) or len(temp_label) > 25:
                            res.append(['', temp_label + text])
                        else:
                            res.append([temp_label,text])
                        temp_label = ''


        texts_only = []
        texts_with_title = []

        isStart = True
        temp = ''
        temp_title = ''

        for k in res :
            if isStart :
                  
                if k[0] != '':
                    if k[1][-1] == '。':
                        temp = temp + k[1]
                        temp = clean_data(temp)
                        temp_title = temp_title + k[0]

                        texts_with_title.append([temp_title,temp])

                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)
                        
                        # reset
                        
                        temp = ''
                        temp_title = ''      
                        isStart = False
                    else:
                        temp = temp + k[1]
                        temp_title = temp_title + k[0]

                if k[0] == '':
                    if k[1][-1] == '。':
                        temp = temp + k[1]
                        temp = clean_data(temp)
                        temp_title = temp_title
                        texts_with_title.append([temp_title,temp])

                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)
                        
                        # reset
                        
                        temp = ''
                        temp_title = ''      
                        isStart = False
                    else:
                        temp = temp + k[1]
                        temp_title = temp_title
            else:
                if k[0] == '':
                    texts_only[-1] = texts_only[-1] + k[1]
                    texts_with_title[-1][1] = texts_with_title[-1][1] + k[1]
                else:
                    temp = k[1]
                    temp_title = k[0]

                    if k[1][-1] == '。':
                        temp = clean_data(temp)
                        texts_with_title.append([temp_title,temp])
                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)
                        temp = ''
                        temp_title = ''       

                    else:
                        isStart = True

        return texts_only,texts_with_title    

def read_html(fileName):

    soup = BeautifulSoup(open(fileName,encoding='utf-8'),features='html.parser')
    res = []
    nums = ['0','1','2','3','4','5','6','7','8','9','10','11','12','13','14']
    marks = ['。','！','…','？','?','!','；',';','，']
    temp_label = ''   # 段落标签
    is_merge = False  # 针对pdf的分页

    for s in soup.strings:
        s = removeLineFeed(s)
        text = s.replace(' ','')
        if text != '':
            if text in nums:
                is_merge = True
                continue
            if len(text) < 2:
                continue                 
            if is_merge :
                is_merge = False
                if len(res) > 0:
                    res[-1][1] = res[-1][1] + clean_data(text) 
                temp_label = ''
                continue
            if text[0] in nums and text[1] == '.':
                start = 1
                for i in range(1,len(text)-1):
                    if text[i] in nums or text[i] == '.':
                        start = i  
                    else:
                        break
                temp_label = ''
                text = text[start+1:]   
            if text == '':
                continue
            isHasMark = False
            for mk in marks:
                if mk in text:
                    isHasMark = True
                    break
            if len(text) < 18 and not isHasMark:
                temp_label = text
            if '    ' in text:
                s = text.find('     ')
                temp_label = text[:s]
                text = text[s:]
            if len(text) > 18 or text[-1] == '。':
                temp_label = clean_data(temp_label)
                text = clean_data(text)
                res.append([temp_label,text])
                temp_label = ''

    texts_only = []
    texts_with_title = []
    isStart = True
    temp = ''
    temp_title = ''
    for k in res :
        if isStart :                  
            if k[0] != '':
                if k[1][-1] == '。':
                    temp = temp + k[1]
                    temp = clean_data(temp)
                    temp_title = temp_title + k[0]
                    texts_with_title.append([temp_title,temp])
                    temp_list = split_to_sents(temp,(2,128))
                    for t in temp_list:
                        texts_only.append(t)                       
                    temp = ''
                    temp_title = ''      
                    isStart = False
                else:
                    temp = temp + k[1]
                    temp_title = temp_title + k[0]
            if k[0] == '':
                if k[1][-1] != '' and k[1][-1] == '。':
                    temp = temp + k[1]
                    temp = clean_data(temp)
                    temp_title = temp_title
                    texts_with_title.append([temp_title,temp])
                    temp_list = split_to_sents(temp,(2,128))
                    for t in temp_list:
                        texts_only.append(t)                
                    temp = ''
                    temp_title = ''      
                    isStart = False
                else:
                    temp = temp + k[1]
                    temp_title = temp_title
        else:
            if k[0] == '':
                texts_only[-1] = texts_only[-1] + k[1]
                texts_with_title[-1][1] = texts_with_title[-1][1] + k[1]
            else:
                temp = k[1]
                temp_title = k[0]
                if k[1][-1] == '。':
                    temp = clean_data(temp)
                    texts_with_title.append([temp_title,temp])
                    temp_list = split_to_sents(temp,(2,128))
                    for t in temp_list:
                        texts_only.append(t)
                    temp = ''
                    temp_title = ''       
                else:
                    isStart = True

    return texts_with_title

def read_xml(fileName):

    soup = BeautifulSoup(open(fileName,encoding='utf-8'),features='lxml')

    res = []
    nums = ['0','1','2','3','4','5','6','7','8','9','10','11','12','13','14']
    temp_label = ''   # 段落标签
    is_merge = False  # 针对pdf的分页

    for s in soup.strings:
        s = removeLineFeed(s)
        text = s.replace(' ','')

    for s in soup.strings:
        s = removeLineFeed(s)
        text = s.replace(' ','')
        if text != '':

            if text in nums:
                is_merge = True
                continue
            if len(text) < 2:
                continue                 
            if is_merge :
                is_merge = False
                if len(res) > 0:
                    res[-1][1] = res[-1][1] + clean_data(text) 
                temp_label = ''
                continue
            if text[0] in nums and text[1] == '.':
                start = 1
                for i in range(1,len(text)-1):
                    if text[i] in nums or text[i] == '.':
                        start = i  
                    else:
                        break
                temp_label = ''
                text = text[start+1:]   
            if text == '':
                continue
            if len(text) < 18 and not isHasMark(text):
                temp_label = text
            if '    ' in text:
                s = text.find('     ')
                temp_label = text[:s]
                text = text[s:]
            if len(text) > 18 or text[-1] == '。':
                temp_label = clean_data(temp_label)
                text = clean_data(text)
                if isHasMark(temp_label) or len(temp_label) > 25:
                    res.append(['', temp_label + text])
                else:
                    res.append([temp_label,text])
                temp_label = ''

    texts_only = []
    texts_with_title = []
    isStart = True
    temp = ''
    temp_title = ''

    for count,k in enumerate(res):    
        if isStart :                  
            if k[0] != '':
                if k[1][-1] == '。':
                    temp = temp + k[1]
                    temp = clean_data(temp)
                    temp_title = temp_title + k[0]
                    texts_with_title.append([temp_title,temp])
                    temp_list = split_to_sents(temp,(2,128))
                    for t in temp_list:
                        texts_only.append(t)                       
                    temp = ''
                    temp_title = ''      
                    isStart = False
    
                else:
                    temp = temp + k[1]
                    temp_title = temp_title + k[0]
    
            if k[0] == '':
                if k[1] != '':
                    if k[1][-1] == '。':
                        temp = temp + k[1]
                        temp = clean_data(temp)
                        temp_title = temp_title
                        texts_with_title.append([temp_title,temp])
                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)                
                        temp = ''
                        temp_title = ''      
                        isStart = False

                    else:
                        temp = temp + k[1]
                        temp_title = temp_title

        else:
            if k[0] == '':
                texts_only[-1] = texts_only[-1] + k[1]
                texts_with_title[-1][1] = texts_with_title[-1][1] + k[1]

            else:
                temp = k[1]
                temp_title = k[0]

                if count != len(res) - 1:
                    
                    # 2020/12/21 更新 增加判断 如果上一个标题以':'结束 且下一个标题并不为空则判断为不相关标题
                    if k[1][-1] == '。' or (k[1][-1] == '：' and res[count+1] != '') or  isHasPrefix:
                        temp = clean_data(temp)
                        texts_with_title.append([temp_title,temp])
                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)
                        temp = ''
                        temp_title = ''  
                    else:
                        isStart = True

                else :

                    if k[1][-1] == '。' :
                        temp = clean_data(temp)
                        texts_with_title.append([temp_title,temp])
                        temp_list = split_to_sents(temp,(2,128))
                        for t in temp_list:
                            texts_only.append(t)
                        temp = ''
                        temp_title = ''

                    else:
                        isStart = True
    return texts_with_title                   


from fairies import same_pinyin
from fairies import same_stroke
from fairies import hanzi

def get_tongyin():
    
    return same_pinyin.tongyin

def get_tongxing():
   
    return same_stroke.tongxing

def get_hanzi():

    return hanzi.hanzi
